==> scanbot_sdk-2.9.0.tar.gz: lib/license_plate_scan_data.dart <==
import 'dart:ui';

import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

import 'common_data.dart';

part 'license_plate_scan_data.g.dart';

/// Result of license plate scanning
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class LicensePlateScanResult extends Result {
  /// The country code of the license plate
  String countryCode = '';

  /// The number on the license plate
  String licensePlate = '';

  /// The raw detected text
  String rawText = '';

  /// The confidence of the recognition
  double confidence = 0;

  LicensePlateScanResult(
      {this.countryCode = '',
      this.licensePlate = '',
      this.rawText = '',
      this.confidence = 0.0});

  LicensePlateScanResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  LicensePlateScanResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory LicensePlateScanResult.fromJson(Map<String, dynamic> json) =>
      _$LicensePlateScanResultFromJson(json);

  Map<String, dynamic> toJson() => _$LicensePlateScanResultToJson(this);
}

/// License plate rtu-ui scanner configuration class
@JsonSerializable(includeIfNull: false, explicitToJson: true)
class LicensePlateScannerConfiguration {
  /// The background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarBackgroundColor;

  /// The color of the inactive buttons on the toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsInactiveColor;

  /// The color of the titles of all buttons in the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsColor;

  /// The background color outside the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? cameraOverlayColor;

  /// The color of the finder window's outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderLineColor;

  /// The color of the text hint under the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderTextHintColor;

  /// The title of the cancel button.
  String? cancelButtonTitle;

  /// The title of the dialog with scanned plate confirmation.
  String? confirmationDialogTitle;

  /// Message of the dialog with scanned plate confirmation.
  String? confirmationDialogMessage;

  /// Text on the retry scanning button of the dialog with scanned plate confirmation.
  String? confirmationDialogRetryButtonTitle;

  /// Text on the confirm scanning button of the dialog with scanned plate confirmation.
  String? confirmationDialogConfirmButtonTitle;

  /// The color of buttons of the dialog with scanned plate confirmation.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? confirmationDialogAccentColor;

  /// Whether the confirmation button should be filled with color, or should rather only be a text button
  bool? confirmationDialogConfirmButtonFilled;

  /// If the confirmation button is filled, then this option selects the color of the text for this button
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? confirmationDialogConfirmButtonFilledTextColor;

  /// The minimum number of sequentially recognized frames where the result is equal
  int? minNumberOfRequiredFramesWithEqualRecognitionResult;

  /// Maximum number of accumulated frames to inspect before the actual result is returned
  int? maximumNumberOfAccumulatedFrames;

  /// The title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String? enableCameraButtonTitle;

  /// Text that will be displayed when the app
  /// is not allowed to use the camera, prompting the user
  /// to enable the usage of the camera.
  String? enableCameraExplanationText;

  /// The text hint shown under the finder window.
  String? finderTextHint;

  /// Width of the finder frame border.
  int? finderLineWidth;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  /// Whether we need to show buttons text in caps mode or not
  /// Android only
  bool? useButtonsAllCaps;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.
  CameraOrientationMode? orientationLockMode;

  LicensePlateScannerConfiguration(
      {this.topBarBackgroundColor,
      this.topBarButtonsInactiveColor,
      this.topBarButtonsColor,
      this.cameraOverlayColor,
      this.finderLineColor,
      this.finderTextHintColor,
      this.cancelButtonTitle,
      this.confirmationDialogTitle,
      this.confirmationDialogMessage,
      this.confirmationDialogRetryButtonTitle,
      this.confirmationDialogConfirmButtonTitle,
      this.confirmationDialogAccentColor,
      this.confirmationDialogConfirmButtonFilled,
      this.confirmationDialogConfirmButtonFilledTextColor,
      this.minNumberOfRequiredFramesWithEqualRecognitionResult,
      this.maximumNumberOfAccumulatedFrames,
      this.enableCameraButtonTitle,
      this.enableCameraExplanationText,
      this.finderTextHint,
      this.finderLineWidth,
      this.flashEnabled,
      this.useButtonsAllCaps,
      this.orientationLockMode});

  factory LicensePlateScannerConfiguration.fromJson(
          Map<String, dynamic> json) =>
      _$LicensePlateScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() =>
      _$LicensePlateScannerConfigurationToJson(this);
}

==> scanbot_sdk-2.10.0.tar.gz: lib/license_plate_scan_data.dart <==
import 'dart:ui';

import 'package:json_annotation/json_annotation.dart';
import 'package:scanbot_sdk/sdk_utils.dart';

import 'json/common_data.dart';

part 'license_plate_scan_data.g.dart';

/// Result of license plate scanning
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class LicensePlateScanResult extends Result {
  /// The country code of the license plate
  String countryCode = '';

  /// The number on the license plate
  String licensePlate = '';

  /// The raw detected text
  String rawText = '';

  /// The confidence of the recognition
  double confidence = 0;

  LicensePlateScanResult(
      {this.countryCode = '',
      this.licensePlate = '',
      this.rawText = '',
      this.confidence = 0.0});

  LicensePlateScanResult.error(String message) {
    operationResult = OperationResult.ERROR;
    this.message = message;
  }

  LicensePlateScanResult.canceled() {
    operationResult = OperationResult.CANCELED;
  }

  factory LicensePlateScanResult.fromJson(Map<String, dynamic> json) =>
      _$LicensePlateScanResultFromJson(json);

  Map<String, dynamic> toJson() => _$LicensePlateScanResultToJson(this);
}

/// License plate rtu-ui scanner configuration class
@JsonSerializable(includeIfNull: false, explicitToJson: true)
class LicensePlateScannerConfiguration {
  /// The background color of the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarBackgroundColor;

  /// The color of the inactive buttons on the toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsInactiveColor;

  /// The color of the titles of all buttons in the top toolbar.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? topBarButtonsColor;

  /// The background color outside the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? cameraOverlayColor;

  /// The color of the finder window's outline.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderLineColor;

  /// The color of the text hint under the finder window.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? finderTextHintColor;

  /// The title of the cancel button.
  String? cancelButtonTitle;

  /// The title of the dialog with scanned plate confirmation.
  String? confirmationDialogTitle;

  /// Message of the dialog with scanned plate confirmation.
  String? confirmationDialogMessage;

  /// Text on the retry scanning button of the dialog with scanned plate confirmation.
  String? confirmationDialogRetryButtonTitle;

  /// Text on the confirm scanning button of the dialog with scanned plate confirmation.
  String? confirmationDialogConfirmButtonTitle;

  /// The color of buttons of the dialog with scanned plate confirmation.
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? confirmationDialogAccentColor;

  /// Whether the confirmation button should be filled with color, or should rather only be a text button
  bool? confirmationDialogConfirmButtonFilled;

  /// If the confirmation button is filled, then this option selects the color of the text for this button
  @JsonKey(fromJson: colorFromString, toJson: toColorString)
  Color? confirmationDialogConfirmButtonFilledTextColor;

  /// The minimum number of sequentially recognized frames where the result is equal
  int? minNumberOfRequiredFramesWithEqualRecognitionResult;

  /// Maximum number of accumulated frames to inspect before the actual result is returned
  int? maximumNumberOfAccumulatedFrames;

  /// The title of the button that opens the screen where the user can allow
  /// the usage of the camera by the app.
  String? enableCameraButtonTitle;

  /// Text that will be displayed when the app
  /// is not allowed to use the camera, prompting the user
  /// to enable the usage of the camera.
  String? enableCameraExplanationText;

  /// The text hint shown under the finder window.
  String? finderTextHint;

  /// Width of the finder frame border.
  int? finderLineWidth;

  /// Controls whether the flash should be initially enabled.
  /// The default value is FALSE.
  bool? flashEnabled;

  /// Whether we need to show buttons text in caps mode or not
  /// Android only
  bool? useButtonsAllCaps;

  /// Orientation lock mode of the camera: PORTRAIT or LANDSCAPE.
  /// By default the camera orientation is not locked.
  OrientationLockMode? orientationLockMode;

  LicensePlateScannerConfiguration(
      {this.topBarBackgroundColor,
      this.topBarButtonsInactiveColor,
      this.topBarButtonsColor,
      this.cameraOverlayColor,
      this.finderLineColor,
      this.finderTextHintColor,
      this.cancelButtonTitle,
      this.confirmationDialogTitle,
      this.confirmationDialogMessage,
      this.confirmationDialogRetryButtonTitle,
      this.confirmationDialogConfirmButtonTitle,
      this.confirmationDialogAccentColor,
      this.confirmationDialogConfirmButtonFilled,
      this.confirmationDialogConfirmButtonFilledTextColor,
      this.minNumberOfRequiredFramesWithEqualRecognitionResult,
      this.maximumNumberOfAccumulatedFrames,
      this.enableCameraButtonTitle,
      this.enableCameraExplanationText,
      this.finderTextHint,
      this.finderLineWidth,
      this.flashEnabled,
      this.useButtonsAllCaps,
      this.orientationLockMode});

  factory LicensePlateScannerConfiguration.fromJson(
          Map<String, dynamic> json) =>
      _$LicensePlateScannerConfigurationFromJson(json);

  Map<String, dynamic> toJson() =>
      _$LicensePlateScannerConfigurationToJson(this);
}
